     function[latgd] = gc2gd(latgc,altkm);
%
% Latitude conversion: Geocentric to Geodetic 
%    
%              J.Clynch  1990 ftn to matlab 1995
%              added default a,f via common 1998
% Input
%    latgc  = geocentric lat in degrees
%    altkm  = height above ellipsoid given in km
%
% Output
%    latfd  = geodetic lat in degrees
%


%         Defaults to WGS 84
%                     Change via global variables if needed
%
%
%      ==============================================================
%                       ++ GLOBAL VARIABLES  ++
%
%       A_EARTH     if this and F_EARTH are present, defines ellipsoid
%       F_EARTH     "   "    "  A_EARTH  "    "         "      "     
%
     global   A_EARTH F_EARTH
%
%    ================================================================
%   

% Function Body

dtr = pi/180.;
rtd = 180./pi;

%
      a       =   6378.137D00 ;
      feth    =   0.335281066474D-2;
%
%              use global values if exist for ellipsoid
%
      tstell1 =   exist('A_EARTH');
      tstell2 =   exist('F_EARTH');
      if tstell1==1 &  tstell2==1, 
         szAE = size(A_EARTH);
         tstell3=max(szAE);
         if tstell3 > 0, 
            a      = A_EARTH;
            feth   = F_EARTH;
         end;
      end;
%
      b      = a * ( 1.0 - feth );
      eccsq  = 2*feth - feth^2;
%
%         ----------------------------------

%     Use GD or GC to get NU and correction ratio
%     iterate once

     slat    = sin(dtr*latgc);
     rnu     = a ./ sqrt(1.0 - eccsq * (slat.^2));
     ratio   = 1.0 - ((eccsq*rnu) ./ (rnu + altkm));
     
     tanphi  = tan(dtr*latgc) ./ ratio;
     phi     = atan(tanphi);
     latgd   = phi/dtr;

     slat    = sin(dtr*latgd);
     rnu     = a ./ sqrt(1.0 - eccsq * (slat.^2));
     ratio   = 1.0 - ((eccsq*rnu) ./ (rnu + altkm));

     tanphi  = tan(dtr*latgc) ./ ratio;
     phi     = atan(tanphi);
     latgd   = phi/dtr;
%
     return;
