        function [eca_deg, az_deg] = gcircle(lata,lona,latb,lonb)
%
%
%         earth central angle along great circle between two points
%
%           ============= not vectorized !!  ==================
%
%     input:
%              lata,lona      latitude, longitude point A in deg
%              latb,lonb         "          "      "
%     output:
%              eca_deg        earth central angle in deg along great
%                             circle
%              az_deg         azimuth of take of from A to B

%    From Fossell Ch 1 - single quadrant example
%

      rtd  =  180.0D0/pi;
      dtr  =  1.0D0/rtd;
%
      clata =  cos(dtr*lata);
      clatb =  cos(dtr*latb);
      slata =  sin(dtr*lata);
      slatb =  sin(dtr*latb);
      cdlon =  cos(dtr*(lona - lonb) );
      sdlon =  sin(dtr*(lonb - lona) );
%
%         the arc lenght "u"
%
      cu    =  slata*slatb + clata*clatb*cdlon;
      urad  =  acos(cu);
%
      eca_deg =  rtd*urad;
%
%         take off az
%
      azrad  = 0.0;
      if urad < 1.0E-9
         azrad = 0.0;
      else
         saz   =  clatb*sdlon/sin(urad);
         if saz> 1.0 ; saz = 1.0; end;
         if saz<-1.0 ; saz =-1.0; end;
         azrad =  asin ( saz );
      end
%
      az_deg = rtd * azrad;
%
%              quadrant
%
      if latb < lata ;  az_deg = 180.0 - az_deg;  end;
%

      if az_deg <0 ; az_deg=az_deg+360; end;
%
      return;
