     function[x] = llhxyz(latgd,lon,altkm);
%
% Converts latitude, longitude and height to cartesian coordinates using old
% geodetic system ellipsoid

% Bomford/Moritz Algorithm
%
%         J.R. Clynch 10-98  From 1985 fortran 
%         

% Uses rminor (at latgd through major to semi-minor axis length)

% Input
%    latgd  = geodetic latitude in degrees
%    lon    = longitude in degrees
%    altkm  = altitude (ellipsoid height) in km
%          --- scalars  or column vectors  ---
%
% Output
%
%    x = cartesian coordinate matrix containing x, y, z (km)
%

%         Defaults to WGS 84
%                     Change via global variables if needed
%
%
%      ==============================================================
%                       ++ GLOBAL VARIABLES  ++
%
%       A_EARTH     if this and F_EARTH are present, defines ellipsoid
%       F_EARTH     "   "    "  A_EARTH  "    "         "      "     
%
     global   A_EARTH F_EARTH
%
%    ================================================================
%   

% Function Body

     dtr = pi/180.;
     rtd = 180./pi;

%
      a       =   6378.137D00 ;
      feth    =   0.335281066474D-2;
%
%              use global values if exist for ellipsoid
%
      tstell1 =   exist('A_EARTH');
      tstell2 =   exist('F_EARTH');
      if tstell1==1 &  tstell2==1, 
         szAE = size(A_EARTH);
         tstell3=max(szAE);
         if tstell3 > 0, 
            a      = A_EARTH;
            feth   = F_EARTH;
         end;
      end;
%
      b      = a * ( 1.0 - feth );
      eccsq  = 2*feth - feth^2;
%
%              --------------------------------------------
%
     slatgd = sin(dtr*latgd);
     clatgd = cos(dtr*latgd);
     slon   = sin(dtr*lon);
     clon   = cos(dtr*lon);

     Rn = a ./ sqrt(1.0-(eccsq*(slatgd.^2)));

     x1 = (Rn + altkm) .* clatgd .* clon;
     x2 = (Rn + altkm) .* clatgd .* slon;
     x3 = ((1.0-eccsq) * Rn + altkm) .* slatgd;

     x  = [x1 x2 x3];

     return;
