function[radearth] = rearth(flati,akm,eccsq);

% Get earth ellipsoid radius from Geocentric Lat using new ellipsoid parameters

% Input
%	flati = geodetic latitude in degrees
% 	akm = semi-major axis in km
% 	eccsq = square of eccentricity (1 - b**2/a**2)
% Output
%	radearth = radius of earth for new ellipsoid (km)

% Function Variables
% 	rminsq = a*a*(1-ecc) = b**2
% 	dtr = degrees to radians

% Function Body

dtr = .017453292519943;

clat = cos(dtr*flati);
rminsq = akm*akm*(1.0 - eccsq);
resq = rminsq / (1.0 - eccsq*(clat^2));
radearth = sqrt(resq);

return