function[radearth] = rearthc(latgc);

% Get earth ellipsoid radius from Geocentric Lat 
% using new ellipsoid parameters
%
%         J.R. Clynch  10-98  from 1985 fortran

% Input
%    latgc    = geodetic latitude in degrees
%
% Output
%
%    radearth = radius of earth for new ellipsoid (km)

%
%         Defaults to WGS 84
%                     Change via global variables if needed
%
%
%      ==============================================================
%                       ++ GLOBAL VARIABLES  ++
%
%       A_EARTH     if this and F_EARTH are present, defines ellipsoid
%       F_EARTH     "   "    "  A_EARTH  "    "         "      "     
%
     global   A_EARTH F_EARTH
%
%    ================================================================
%   


% Function Body
%
      a       =   6378.137D00 ;
      feth    =   0.335281066474D-2;
%
%              use global values if exist for ellipsoid
%
      tstell1 =   exist('A_EARTH');
      tstell2 =   exist('F_EARTH');
      if tstell1==1 &  tstell2==1, 
         szAE = size(A_EARTH);
         tstell3=max(szAE);
         if tstell3 > 0, 
            a      = A_EARTH;
            feth   = F_EARTH;
         end;
      end;
%

b     =  a * (1.0 - feth);
eccsq =  2.0*feth - feth*feth;


dtr = pi/180.;


clat = cos(dtr*latgc);

rminsq = b*b;
resq = rminsq ./ (1.0 - eccsq*(clat.^2));
radearth = sqrt(resq);

return;
