function[eradius] = rearthg(latgd)

% This function finds the radius
% of the earth (km) at a given geographic latitude 
% assuming an ellipsoid earth.
%
%         J.R. Clynch  10-98   from 1985 fortran
%
% Input
%
%    latgd = geodetic latitude (radians)
%
% Output
%
%    eradius = radius of earth (km)

%
%         Defaults to WGS 84
%                     Change via global variables if needed
%
%
%      ==============================================================
%                       ++ GLOBAL VARIABLES  ++
%
%       A_EARTH     if this and F_EARTH are present, defines ellipsoid
%       F_EARTH     "   "    "  A_EARTH  "    "         "      "     
%
     global   A_EARTH F_EARTH
%
%    ================================================================
%   


% Function Body

      a       =   6378.137D00 ;
      feth    =   0.335281066474D-2;
%
%              use global values if exist for ellipsoid
%
      tstell1 =   exist('A_EARTH');
      tstell2 =   exist('F_EARTH');
      if tstell1==1 &  tstell2==1, 
         szAE = size(A_EARTH);
         tstell3=max(szAE);
         if tstell3 > 0, 
            a      = A_EARTH;
            feth   = F_EARTH;
         end;
      end;
%

dtr  = pi/180.;

b     =  a * (1.0 - feth);
eccsq =  2.0*feth - feth*feth;

clatsq = cos(dtr*latgd).^2;
slatsq = 1.0 - clatsq;
ratio  = (1. - eccsq)^2;
rminsq =  a^2 * ( ratio*slatsq + clatsq);
resq = rminsq ./ (1.0 - eccsq * slatsq);
eradius = sqrt(resq);

return;
