function[eradius] = rxearth(gdlat,akm,eccsq)

% This function uses the actual formula that rearth approximates to find the radius
% of the earth (km) at a given geographic latitude assuming an ellipsoid earth.

% Input
% 	akm   = semi-major axis in km
%	eccsq = square of eccentricity (1 - b^2/a^2) = (2f - f^2)
% 	gdlat = geodetic latitude (radians)
% Output
%	eradius = radius of earth (km)

% Function Body

clatsq = cos(gdlat) * cos(gdlat);
slatsq = 1.0 - clatsq;
rminsq = (akm^2)*(((1.0 - eccsq)^2) * slatsq + clatsq);
resq = rminsq / (1.0 - eccsq * slatsq);
eradius = sqrt(resq);

return